pub fn create_bench_cluster(
num_shards: u32,
) -> (Arc<Coordinator>, Vec<Arc<RwLock<ShardedColony>>>)Expand description
Create a test cluster for benchmarking.
Returns the coordinator and a vector of sharded colonies.
pub fn create_bench_cluster(
num_shards: u32,
) -> (Arc<Coordinator>, Vec<Arc<RwLock<ShardedColony>>>)Create a test cluster for benchmarking.
Returns the coordinator and a vector of sharded colonies.