run_benchmark

Function run_benchmark 

pub async fn run_benchmark(config: BenchConfig) -> BenchResults
Run the full benchmark suite.

This is an async function that creates a distributed cluster, ingests documents, runs ticks, and executes queries to measure performance.