Module protocol

Module protocol 

tarpc service trait definitions.

This module defines the RPC service interfaces for distributed colony coordination using tarpc’s procedural macro system.

Structs

CoordinatorServiceClient
The client stub that makes RPC calls to the server. All request methods return Futures.
ServeCoordinatorService
A serving function to use with ::tarpc::server::InFlightRequest::execute.
ServeShardService
A serving function to use with ::tarpc::server::InFlightRequest::execute.
ShardServiceClient
The client stub that makes RPC calls to the server. All request methods return Futures.
TickStatus
Status of the current tick across all shards.

Enums

CoordinatorServiceRequest
The request sent over the wire from the client to the server.
CoordinatorServiceResponse
The response sent over the wire from the server to the client.
RpcError
Serializable error type for RPC calls.
ShardServiceRequest
The request sent over the wire from the client to the server.
ShardServiceResponse
The response sent over the wire from the server to the client.

Traits

CoordinatorService
Service provided by the coordinator.
CoordinatorServiceStub
The stub trait for service CoordinatorService.
ShardService
Service provided by each shard in the distributed colony.
ShardServiceStub
The stub trait for service ShardService.

Type Aliases

RpcResult
Result type for RPC operations that needs to be serializable.