pub async fn run_benchmark(config: BenchConfig) -> BenchResultsExpand description
Run the full benchmark suite.
This is an async function that creates a distributed cluster, ingests documents, runs ticks, and executes queries to measure performance.