tarpc service trait definitions.
This module defines the RPC service interfaces for distributed colony coordination using tarpc’s procedural macro system.
Structs
- Coordinator
Service Client - The client stub that makes RPC calls to the server. All request methods return Futures.
- Serve
Coordinator Service - A serving function to use with ::tarpc::server::InFlightRequest::execute.
- Serve
Shard Service - A serving function to use with ::tarpc::server::InFlightRequest::execute.
- Shard
Service Client - The client stub that makes RPC calls to the server. All request methods return Futures.
- Tick
Status - Status of the current tick across all shards.
Enums
- Coordinator
Service Request - The request sent over the wire from the client to the server.
- Coordinator
Service Response - The response sent over the wire from the server to the client.
- RpcError
- Serializable error type for RPC calls.
- Shard
Service Request - The request sent over the wire from the client to the server.
- Shard
Service Response - The response sent over the wire from the server to the client.
Traits
- Coordinator
Service - Service provided by the coordinator.
- Coordinator
Service Stub - The stub trait for service
CoordinatorService. - Shard
Service - Service provided by each shard in the distributed colony.
- Shard
Service Stub - The stub trait for service
ShardService.
Type Aliases
- RpcResult
- Result type for RPC operations that needs to be serializable.