pub struct CoordinatorServer { /* private fields */ }Expand description
Server implementation for the coordinator.
CoordinatorServer wraps a Coordinator and implements the CoordinatorService
trait, allowing shards and clients to interact with the coordinator via tarpc RPC.
Thread Safety
The coordinator is wrapped in Arc as it uses interior mutability
(RwLock, AtomicU64) for thread-safe access.
Example
ⓘ
use phago_distributed::rpc::server::CoordinatorServer;
use phago_distributed::coordinator::Coordinator;
let coordinator = Arc::new(Coordinator::new(3));
let server = CoordinatorServer::new(coordinator);
server.serve("127.0.0.1:8080".parse().unwrap()).await?;Implementations
Sourceimpl CoordinatorServer
impl CoordinatorServer
Sourcepub fn new(coordinator: Arc<Coordinator>) -> Self
pub fn new(coordinator: Arc<Coordinator>) -> Self